@@ -5,5 +5,6 @@ from .base import UserProxyModel, Constants, exceptions as exc
 from .context import ctx
 from .loader import logger
 from .run import run
+from .utils import html
 
-__all__ = ['on', 'objects', 'bot', 'UserProxyModel', 'Constants', 'ctx', 'run', 'exc', 'logger']
+__all__ = ['on', 'objects', 'bot', 'UserProxyModel', 'Constants', 'ctx', 'run', 'exc', 'logger', 'html']
